@@ -1,7 +1,4 @@
-package # hide from PAUSE
-    DBIx::Class::CDBICompat::Constraints;
-
-use base 'DBIx::Class';
+package DBIx::Class::CDBICompat::Constraints;
 
 use strict;
 use warnings;
@@ -18,7 +15,7 @@ sub constrain_column {
   } elsif (ref $how eq "Regexp") {
     $class->add_constraint(regexp => $col => sub { shift =~ $how });
   } else {
-    $how =~ m/([^:]+)$/; # match is safe - we throw above on empty $how
+    $how =~ m/([^:]+)$/;
     my $try_method = sprintf '_constrain_by_%s', lc $1; # $how->moniker;
     if (my $dispatch = $class->can($try_method)) {
       $class->$dispatch($col => ($how, @_));
