@@ -8,17 +8,21 @@ use base qw/DBIx::Class/;
 __PACKAGE__->load_components(qw/PK::Auto/);
 
 sub last_insert_id {
-  return $_[0]->storage->dbh->{mysql_insertid};
+  return $_[0]->result_source->storage->dbh->{mysql_insertid};
 }
 
 1;
 
 =head1 NAME 
 
-DBIx::Class::PK::Auto::MySQL - Automatic Primary Key class for MySQL
+DBIx::Class::PK::Auto::MySQL - Automatic primary key class for MySQL
 
 =head1 SYNOPSIS
 
+  # In your table classes
+  __PACKAGE__->load_components(qw/PK::Auto::MySQL Core/);
+  __PACKAGE__->set_primary_key('id');
+
 =head1 DESCRIPTION
 
 This class implements autoincrements for MySQL.
@@ -32,4 +36,3 @@ Matt S. Trout <mst@shadowcatsystems.co.uk>
 You may distribute this code under the same terms as Perl itself.
 
 =cut
-
