@@ -1,10 +1,7 @@
-package # hide from PAUSE 
-    DBICTest::Extra::Foo;
+package DBICTest::Extra::Foo;
 use base 'DBIx::Class';
 
 __PACKAGE__->load_components(qw/ ResultSetManager Core /);
 __PACKAGE__->table('foo');
 
 sub bar : ResultSet { 'good' }
-
-1;
