@@ -1,5 +1,4 @@
-package # hide from PAUSE 
-    DBICTest::Plain;
+package DBICTest::Plain;
 
 use strict;
 use warnings;
